@@ -137,10 +137,11 @@ class Hirarchy(object, metaclass=IterRegistry):
         return self._name
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str,inherit=True):
         self._name = value
-        for child in self.children:
-            child.name = value
+        if inherit:
+            for child in self.children:
+                child.name = value
         self.changed = True
 
     @property
